unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ComCtrls, ToolWin, MSWord, MSWPD, MSWBase, MSWRI, Menus;

type
  TfrmMain = class(TForm)
    OpenDialog: TOpenDialog;
    MSWordDocument1: TMSWordDocument;
    tbMain: TToolBar;
    btnOpen: TToolButton;
    ImageList: TImageList;
    btnStatistic: TToolButton;
    btnSeparator1: TToolButton;
    btnClose: TToolButton;
    btnAbout: TToolButton;
    btnOrder: TToolButton;
    btnSeparator2: TToolButton;
    pcDocument: TPageControl;
    tsPlainText: TTabSheet;
    memoDocument: TMemo;
    tsMacros: TTabSheet;
    memoMacros: TMemo;
    WordPerfectFile1: TWordPerfectFile;
    WRIFile1: TWRIFile;
    procedure btnOpenClick(Sender: TObject);
    procedure btnCloseClick(Sender: TObject);
    procedure btnOrderClick(Sender: TObject);
    procedure btnStatisticClick(Sender: TObject);
    procedure btnAboutClick(Sender: TObject);
    procedure MSWordDocument1ConvertSysChar(Sender: TObject;
      SysChar: TSMWordSysChar; Value: string; var Result: String);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}
{$R winxp.res}

uses ShellAPI, SumInfo;

procedure TfrmMain.btnOpenClick(Sender: TObject);
var
  strExt: string;
  StartTick, EndTick: Integer;
begin
  if OpenDialog.Execute then
  begin
    strExt := UpperCase(ExtractFileExt(OpenDialog.FileName));
    if (strExt = '.WPD') then
    begin
      WordPerfectFile1.FileName := OpenDialog.FileName;
      WordPerfectFile1.Execute;

      memoDocument.Lines.Text := WordPerfectFile1.PlainText.Text;
    end
    else
    if (strExt = '.WRI') then
    begin
      WRIFile1.FileName := OpenDialog.FileName;
      WRIFile1.Execute;

      memoDocument.Lines.Text := WRIFile1.PlainText.Text;
    end
    else
    begin
      MSWordDocument1.ParseVBA := False;//True;
      MSWordDocument1.FileName := OpenDialog.FileName;

      StartTick := GetTickCount;
      MSWordDocument1.Execute;
      EndTick := GetTickCount;
      Caption := IntToStr(EndTick - StartTick + 1) + ' msec';

      memoDocument.Lines.Text := MSWordDocument1.PlainText.Text;
      memoMacros.Lines.Text := MSWordDocument1.MacroText.Text;
    end;
    btnStatistic.Enabled := True
  end;
end;

procedure TfrmMain.btnStatisticClick(Sender: TObject);
begin
  with TfrmSummaryInfo.Create(Application) do
    try
      with lvSummary.Items.Add do
      begin
        Caption := 'FileName';
        SubItems.Add(MSWordDocument1.FileName)
      end;

      with lvSummary.Items.Add do
      begin
        Caption := 'Title';
        SubItems.Add(MSWordDocument1.SummaryInformation.Title)
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'Subject';
        SubItems.Add(MSWordDocument1.SummaryInformation.Subject)
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'Author';
        SubItems.Add(MSWordDocument1.SummaryInformation.Author)
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'Application';
        SubItems.Add(MSWordDocument1.SummaryInformation.AppName)
      end;

      with lvSummary.Items.Add do
      begin
        Caption := 'Keywords';
        SubItems.Add(MSWordDocument1.SummaryInformation.Keywords)
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'Comments';
        SubItems.Add(MSWordDocument1.SummaryInformation.Comments)
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'Template';
        SubItems.Add(MSWordDocument1.SummaryInformation.Template)
      end;

      with lvSummary.Items.Add do
      begin
        Caption := 'LastAuthor';
        SubItems.Add(MSWordDocument1.SummaryInformation.LastAuthor)
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'Created';
        SubItems.Add(DateToStr(MSWordDocument1.SummaryInformation.Created))
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'LastSaved';
        SubItems.Add(DateToStr(MSWordDocument1.SummaryInformation.LastSaved))
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'LastPrinted';
        SubItems.Add(DateToStr(MSWordDocument1.SummaryInformation.LastPrinted))
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'RevNumber';
        SubItems.Add(MSWordDocument1.SummaryInformation.RevNumber)
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'EditTime (min)';
        SubItems.Add(IntToStr(MSWordDocument1.SummaryInformation.EditTime))
      end;

      with lvSummary.Items.Add do
      begin
        Caption := 'PageCount';
        SubItems.Add(IntToStr(MSWordDocument1.SummaryInformation.PageCount))
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'CharCount';
        SubItems.Add(IntToStr(MSWordDocument1.SummaryInformation.CharCount))
      end;
      with lvSummary.Items.Add do
      begin
        Caption := 'WordCount';
        SubItems.Add(IntToStr(MSWordDocument1.SummaryInformation.WordCount))
      end;

      ShowModal
    finally
      Free
    end;
end;

procedure TfrmMain.btnCloseClick(Sender: TObject);
begin
  Close
end;

procedure TfrmMain.btnOrderClick(Sender: TObject);
begin
  ShellExecute(0, 'open', 'http://www.scalabium.com/smorder.htm', nil, nil, SW_SHOWNORMAL);
end;

procedure TfrmMain.btnAboutClick(Sender: TObject);
begin
  Application.MessageBox('TMSWordDocument component, written by Scalabium Software'#13#10 +
                         ''#13#10 +
                         'Allow to read documents created in MS Word without MS Word installed'#13#10 +
                         'Direct and native document processing allow to extract a text very-very fast'#13#10 +
                         ''#13#10 +
                         'For additional tech information or support ask Mike Shkolnik:' + #13#10 +
                         'http://www.scalabium.com, e-mail: mshkolnik@scalabium.com' + #13#10#13#10 +
                         'You can order a product at:  http://www.scalabium.com/smorder.htm'#13#10,
                         'About TMSWordDocument v1.31', MB_OK);
end;

procedure TfrmMain.MSWordDocument1ConvertSysChar(Sender: TObject;
  SysChar: TSMWordSysChar; Value: string; var Result: String);
var
  i: Integer;
begin
  if (SysChar = scColumnEnd) then
    Result := Result + #13#10//#9
  else
  if (SysChar in [scRowEnd]) then
    Result := Result + #13#10
  else
  if (SysChar = scHyperlink) then
  begin
    {remove url, leave text only}
    i := Pos(#$14, Result);
    if (i > 0) then
      Delete(Result, 1, i)

    {to leave the url+text, use the next code instead:
{    i := Pos(#$14, Result);
    if (i > 0) then
      Result[i] := ' '
}
  end
  else
  if (SysChar = scFieldEnd) then
  begin
    {remove url, leave text only}
    i := Pos(#$14, Result);
    if (i > 0) then
      Delete(Result, 1, i)
  end
end;

end.
